@@ -19,11 +19,8 @@ from neutron_lib.api.definitions import allowedaddresspairs
 from neutron_lib.api.definitions import auto_allocated_topology
 from neutron_lib.api.definitions import availability_zone
 from neutron_lib.api.definitions import availability_zone_filter
-from neutron_lib.api.definitions import bfd_for_extraroutes
-from neutron_lib.api.definitions import bfd_monitor
 from neutron_lib.api.definitions import bgp
 from neutron_lib.api.definitions import bgp_4byte_asn
-from neutron_lib.api.definitions import bgp_associations
 from neutron_lib.api.definitions import bgp_dragentscheduler
 from neutron_lib.api.definitions import bgpvpn
 from neutron_lib.api.definitions import bgpvpn_routes_control
@@ -49,7 +46,9 @@ from neutron_lib.api.definitions import extraroute
 from neutron_lib.api.definitions import extraroute_atomic
 from neutron_lib.api.definitions import filter_validation
 from neutron_lib.api.definitions import fip64
+from neutron_lib.api.definitions import fip_distributed
 from neutron_lib.api.definitions import fip_pf_description
+from neutron_lib.api.definitions import fip_pf_detail
 from neutron_lib.api.definitions import fip_pf_port_range
 from neutron_lib.api.definitions import fip_port_details
 from neutron_lib.api.definitions import firewall_v2
@@ -67,7 +66,6 @@ from neutron_lib.api.definitions import l3_ext_gw_mode
 from neutron_lib.api.definitions import l3_ext_ha_mode
 from neutron_lib.api.definitions import l3_ext_ndp_proxy
 from neutron_lib.api.definitions import l3_flavors
-from neutron_lib.api.definitions import l3_multi_ext_gw
 from neutron_lib.api.definitions import l3_ndp_proxy
 from neutron_lib.api.definitions import l3_port_ip_change_not_allowed
 from neutron_lib.api.definitions import local_ip
@@ -78,6 +76,7 @@ from neutron_lib.api.definitions import metering_source_and_destination_filters
 from neutron_lib.api.definitions import multiprovidernet
 from neutron_lib.api.definitions import network
 from neutron_lib.api.definitions import network_availability_zone
+from neutron_lib.api.definitions import network_cascade_delete
 from neutron_lib.api.definitions import network_ip_availability
 from neutron_lib.api.definitions import network_mtu
 from neutron_lib.api.definitions import network_mtu_writable
@@ -85,6 +84,8 @@ from neutron_lib.api.definitions import network_segment_range
 from neutron_lib.api.definitions import pagination
 from neutron_lib.api.definitions import port
 from neutron_lib.api.definitions import port_device_profile
+from neutron_lib.api.definitions import port_hints
+from neutron_lib.api.definitions import port_mac_address_override
 from neutron_lib.api.definitions import port_mac_address_regenerate
 from neutron_lib.api.definitions import port_numa_affinity_policy
 from neutron_lib.api.definitions import port_resource_request
@@ -162,11 +163,8 @@ _ALL_API_DEFINITIONS = {
     auto_allocated_topology,
     availability_zone,
     availability_zone_filter,
-    bfd_for_extraroutes,
-    bfd_monitor,
     bgp,
     bgp_4byte_asn,
-    bgp_associations,
     bgp_dragentscheduler,
     bgpvpn,
     bgpvpn_routes_control,
@@ -193,6 +191,8 @@ _ALL_API_DEFINITIONS = {
     filter_validation,
     fip64,
     firewall_v2,
+    fip_distributed,
+    fip_pf_detail,
     fip_port_details,
     flavors,
     floating_ip_port_forwarding,
@@ -210,7 +210,6 @@ _ALL_API_DEFINITIONS = {
     l3_ext_ha_mode,
     l3_ext_ndp_proxy,
     l3_flavors,
-    l3_multi_ext_gw,
     l3_ndp_proxy,
     l3_port_ip_change_not_allowed,
     local_ip,
@@ -221,6 +220,7 @@ _ALL_API_DEFINITIONS = {
     multiprovidernet,
     network,
     network_availability_zone,
+    network_cascade_delete,
     network_ip_availability,
     network_mtu,
     network_mtu_writable,
@@ -228,6 +228,8 @@ _ALL_API_DEFINITIONS = {
     pagination,
     port,
     port_device_profile,
+    port_hints,
+    port_mac_address_override,
     port_mac_address_regenerate,
     port_numa_affinity_policy,
     port_resource_request,
