@@ -50,12 +50,6 @@ def unsubscribe_all(callback):
     _get_callback_manager().unsubscribe_all(callback)
 
 
-# NOTE(boden): This method is deprecated in favor of publish() and will be
-# removed in Queens, but not deprecation message to reduce log flooding
-def notify(resource, event, trigger, **kwargs):
-    _get_callback_manager().notify(resource, event, trigger, **kwargs)
-
-
 def publish(resource, event, trigger, payload=None):
     _get_callback_manager().publish(resource, event, trigger, payload=payload)
 
@@ -99,6 +93,7 @@ def has_registry_receivers(klass):
             super_new = super(klass, cls).__new__
             if super_new is object.__new__:
                 # object.__new__ doesn't accept args nor kwargs
+                # pylint: disable=no-value-for-parameter
                 instance = super_new(cls)
             else:
                 instance = super_new(cls, *args, **kwargs)
